<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Microsoft.Windows.AppNotifications.Builder

Windows Runtime (WinRT) APIs for for the `Microsoft.Windows.AppNotifications.Builder` namespace.

This package provides the `winrt.microsoft.windows.appnotifications.builder` module.
